@@ -9,4 +9,10 @@
 #' @noRd
 .C_any_neg <- function(x) {
   .Call("C_any_neg", x = x)
+}
+
+#' @keywords Internal
+#' @noRd
+.C_any_badloc <- function(x, y) {
+  .Call("C_any_badloc", x = x, y = y)
 }
\ No newline at end of file
