@@ -6,7 +6,7 @@ using namespace Rcpp;
 //' @keywords internal
 //' @noRd
 // [[Rcpp::export(.rcpp_prep_ns)]]
-List rcpp_prep_ns(List ns, CharacterVector nms, String pkg) {
+List rcpp_prep_ns(const List ns, const CharacterVector nms, const String pkg) {
   R_xlen_t n = nms.length();
   List ns2 = clone(ns);
   for(R_xlen_t i = 0; i < n; ++i) {
